@@ -1,7 +1,7 @@
 package Mail::Audit::List;
 use Mail::Audit;
 use vars q(@VERSION);
-$VERSION = '1.8';
+$VERSION = '1.85';
 1;
 
 package Mail::Audit;
@@ -11,16 +11,19 @@ use Mail::ListDetector;
 my $DEFAULT_DIR = $ENV{HOME} . "/mail";
 
 sub list_accept {
-  my $self = shift;
-  my $dir  = shift;
+  my ($self, $dir, $arg) = @_;
+
   $dir ||= $DEFAULT_DIR;
-  my $list = new Mail::ListDetector($self->{obj});
+  $arg ||= {};
+
+  my $list = Mail::ListDetector->new($self->{obj});
 
   if (!(defined $list)) {
     return 0;
   } else {
     my $name = $list->listname;
     $name =~ tr/A-Za-z0-9_-//dc;
+    $name = $arg->{munge_name}->($name) if $arg->{munge_name};
     my $deliver_filename = join '/', $dir, $name;
     $self->accept($deliver_filename);
     return $deliver_filename;
@@ -53,7 +56,7 @@ C<Mail::ListDetector> module.
 
 =over 4
 
-=item C<list_accept([$delivery_dir])>
+=item C<list_accept($delivery_dir, \%arg)>
 
 Attempts to deliver the message as a mailing list. It will place each 
 message in C<$deliver_dir/$list_name>. The default value of C<$deliver_dir>
@@ -66,6 +69,15 @@ Calls C<accept> and returns the filename delivered to if
 C<Mail::ListDetector> can identify this mail as coming from a mailing
 list, or 0 otherwise. 
 
+Valid named arguments are:
+
+  munge_name - a coderef called to munge the name given by Mail::ListDetector
+
+Note that if you want to use the defailt delivery location, but also to pass
+args, you must call the method like this:
+
+  $audit->list_accept(undef, { ... });
+
 The recipe given above should be able to replace a great number of
 special-casing recipes.
 
